@@ -890,12 +890,12 @@ class ScoreContext(object):
                     staff_context.props.update(staff.m_tdict[timepos]['properties'])
             if timepos == score.m_bars[bar_idx].end():
                 bar = score.m_bars[bar_idx]
-                end = bar.m_timepos + bar.m_timesig.as_rat()
                 for staff_context in staff_contexts:
                     if not staff_context.props['hide-barline']:
                         e = BarlineEngraver("|")
                         staff_context.append(e)
-                        staff_context.m_engravers.setdefault(end, {})['barline'] = e
+                        staff_context.m_engravers.setdefault(
+                            score.m_bars[bar_idx].end(), {})['barline'] = e
                 bar_idx += 1
             def do_col(s, xpos):
                 max_width = 0
